@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef DEVICESMODEL_H
@@ -25,7 +11,7 @@
 #include <QPixmap>
 #include <QList>
 
-#include "interfaces/kdeconnectinterfaces_export.h"
+#include "kdeconnectinterfaces_export.h"
 
 class QDBusPendingCallWatcher;
 class DaemonDbusInterface;
@@ -47,7 +33,7 @@ public:
         IconNameRole,
         DeviceRole
     };
-    Q_ENUM(ModelRoles);
+    Q_ENUM(ModelRoles)
 
     // A device is always paired or reachable or both
     // You can combine the Paired and Reachable flags
@@ -60,7 +46,7 @@ public:
     Q_FLAGS(StatusFilterFlags)
     Q_ENUM(StatusFilterFlag)
 
-    explicit DevicesModel(QObject *parent = nullptr);
+    explicit DevicesModel(QObject* parent = nullptr);
     ~DevicesModel() override;
 
     void setDisplayFilter(int flags);
@@ -71,6 +57,7 @@ public:
 
     Q_SCRIPTABLE DeviceDbusInterface* getDevice(int row) const;
     QHash<int, QByteArray> roleNames() const override;
+    Q_SCRIPTABLE int rowForDevice(const QString& id) const;
 
 private Q_SLOTS:
     void deviceAdded(const QString& id);
@@ -84,10 +71,9 @@ Q_SIGNALS:
     void rowsChanged();
 
 private:
-    int rowForDevice(const QString& id) const;
     void clearDevices();
     void appendDevice(DeviceDbusInterface* dev);
-    bool passesFilter(DeviceDbusInterface *dev) const;
+    bool passesFilter(DeviceDbusInterface* dev) const;
 
     DaemonDbusInterface* m_dbusInterface;
     QVector<DeviceDbusInterface*> m_deviceList;
